<?php
/**
 * @file
 * PxAgreement class for PayEx Autopay agreements.
 */

class PxAgreement extends PxService {
  public static $liveURL = 'https://external.payex.com/pxagreement/pxagreement.asmx?WSDL';
  public static $testURL = 'https://test-external.payex.com/pxagreement/pxagreement.asmx?WSDL';

  /**
   * Implementation of PxAgreement.AutoPay.
   */
  function autoPay($params = array()) {
    // Correct order of the params when hashing.
    $key_order = array('accountNumber', 'agreementRef', 'price', 'productNumber', 'description', 'orderId', 'purchaseOperation', 'currency');

    // Make the SOAP call.
    $call = $this->client->AutoPay3($this->signParams($params, $key_order));
    $response = self::flattenResponse($call->AutoPay3Result);

    if ($response['status']['errorCode'] != 'OK') {
      throw new PayExAPIException($response['status']['description']);
    }
    else {
      return $response;
    }

    // In case of failure, return FALSE.
    return FALSE;
  }

  /**
   * Implementation of PxAgreement.Check.
   */
  function check($params = array()) {
    // Correct order of the params when hashing.
    $key_order = array('accountNumber', 'agreementRef');

    // Make the SOAP call.
    $call = $this->client->Check($this->signParams($params, $key_order));
    $response = self::flattenResponse($call->CheckResult);

    if ($response['status']['errorCode'] != 'OK') {
      throw new PayExAPIException($response['status']['description']);
    }
    else {
      return $response;
    }

    // In case of failure, return FALSE.
    return FALSE;
  }

  /**
   * Implementation of PxAgreement.CreateAgreement.
   */
  function createAgreement($params = array()) {
    // Correct order of the params when hashing.
    $key_order = array('accountNumber', 'merchantRef', 'description', 'purchaseOperation', 'maxAmount', 'notifyUrl', 'startDate', 'stopDate');

    // Make the SOAP call.
    $call = $this->client->CreateAgreement3($this->signParams($params, $key_order));
    $response = self::flattenResponse($call->CreateAgreement3Result);

    if ($response['status']['errorCode'] != 'OK') {
      throw new PayExAPIException($response['status']['description']);
    }
    elseif (!empty($response['agreementRef'])) {
      return $response['agreementRef'];
    }

    // In case of failure, return FALSE.
    return FALSE;
  }

  /**
   * Implementation of PxAgreement.DeleteAgreement.
   */
  function deleteAgreement($params = array()) {
    // Correct order of the params when hashing.
    $key_order = array('accountNumber', 'agreementRef');

    // Make the SOAP call.
    $call = $this->client->DeleteAgreement($this->signParams($params, $key_order));
    $response = self::flattenResponse($call->DeleteAgreementResult);

    if ($response['status']['errorCode'] != 'OK') {
      throw new PayExAPIException($response['status']['description']);
    }
    else {
      return $response;
    }

    // In case of failure, return FALSE.
    return FALSE;
  }
}
