<?php
/**
 * @file
 * PayExAutopayAgreement entity class implementation.
 */

class PayExAutopayAgreement extends Entity {
  /**
   * Returns the "pretty" formatted name for the domain.
   */
  public function defaultLabel() {
    if (!empty($this->owner_entity_id)) {
      return t('Agreement #!num / !type:!id', array(
        '!num' => $this->agreement_id,
        '!type' => $this->owner_entity_type,
        '!id' => $this->owner_entity_id,
      ));
    }

    return $this->agreement_id;
  }

  /**
   * Returns the URL to the standard view of this entity.
   */
  public function defaultUri() {
    return array('path' => 'admin/reports/payex_autopay/' . $this->agreement_id);
  }

  /**
   * Get a payment from this Autopay agreement.
   *
   * @param array $params
   *   An associative array of parameters to be sent to PayEx, with at 
   *   least the following keys set:
   *   - 'price': Price the merchant is charging. The value is passed as 
   *     an integer multiplied by 100. Example 12.00 NOK = 1200.
   *   - 'productNumber': Product number of the product the client is purchasing.
   *   - 'orderId': The merchant should use this parameter to send in a 
   *     local ID identifying this particular order.
   */
  public function autopay($params = array()) {
    // If settings fail to load, bail out, without saving.
    if (!$settings = _payex_get_api_settings()) {
      return FALSE;
    }

    // Default options used if not provided by caller.
    $params += array(
      'agreementRef' => $this->agreement_ref,
      'description' => $this->description,
      'purchaseOperation' => $this->purchase_operation,
      'currency' => $settings['currency'],
    );

    try {
      $pxa = new PxAgreement($settings['merchant_account'],  $settings['encryption_key'], $settings['live']);
      $response = $pxa->autoPay($params);
      return $response;
    }
    catch (Exception $e) {
      watchdog_exception('payex_autopay', $e);
      throw $e;
    }

    return FALSE;
  }

  /**
   * Check the status of an agreement with PayEx.
   *
   * @return integer
   *   Returns the status of an agreement.
   *   - 0: NotVerified
   *   - 1: Verified
   *   - 2: Deleted
   */
  public function check() {
    // If settings fail to load, bail out, without saving.
    if (!$settings = _payex_get_api_settings()) {
      return;
    }

    try {
      $pxa = new PxAgreement($settings['merchant_account'],  $settings['encryption_key'], $settings['live']);
      $response = $pxa->check(array('agreementRef' => $this->agreement_ref));

      return (integer) $response['agreementStatus'];
    }
    catch (Exception $e) {
      watchdog_exception('payex_autopay', $e);
      throw $e;
    }
  }
}
